KaTeX and MathJax Comparison Demo, currently processed as KaTeX
Author: Murray Bourne

Home | Math Display Experiments | MathJax and KaTeX Comparison

# KaTeX and MathJax Comparison Demo

Page by Murray Bourne, IntMath.com. Last updated: 29 Apr 2020

### Repeating fractions

1(ϕ 5−ϕ)e 2 5 π 1+e−2 π 1+e−4 π 1+e−6 π 1+e−8 π 1+⋯\displaystyle \frac{1}{\Bigl(\sqrt{\phi \sqrt{5}}-\phi\Bigr) e^{\frac25 \pi}} \equiv 1+\frac{e^{-2\pi}} {1+\frac{e^{-4\pi}} {1+\frac{e^{-6\pi}} {1+\frac{e^{-8\pi}} {1+\cdots} } } }

### Summation notation

(∑k=1 n a k b k)2≤(∑k=1 n a k 2)(∑k=1 n b k 2)\displaystyle \left( \sum_{k=1}^n a_k b_k \right)^2 \leq \left( \sum_{k=1}^n a_k^2 \right) \left( \sum_{k=1}^n b_k^2 \right)

### Inline math

And here is some in-line math: k n+1=n 2+k n 2−k n−1 k_{n+1} = n^2 + k_n^2 - k_{n-1}, followed by some more text.

### Calculus

∫u d v d x d x=u v−∫d u d x v d x\displaystyle \int u \frac{dv}{dx}\,dx=uv-\int \frac{du}{dx}v\,dx

### Lorenz Equations

x˙=σ(y−x)y˙=ρ x−y−x z z˙=−β z+x y\displaystyle \begin{aligned} \dot{x} & = \sigma(y-x) \\ \dot{y} & = \rho x - y - xz \\ \dot{z} & = -\beta z + xy \end{aligned}

### Case definitions

f(n)={n 2, if n is even 3 n+1, if n is odd\displaystyle f(n) = \begin{cases} \frac{n}{2}, & \text{if } n\text{ is even} \\ 3n+1, & \text{if } n\text{ is odd} \end{cases}

### Matrices

(a 1 1 a 1 2 a 1 3 a 2 1 a 2 2 a 2 3 a 3 1 a 3 2 a 3 3)\displaystyle \begin{pmatrix} a_{11} & a_{12} & a_{13}\\ a_{21} & a_{22} & a_{23}\\ a_{31} & a_{32} & a_{33} \end{pmatrix}